==> haskell-clientsession-0.9.1.1-4-armv7h.pkg.tar.xz: usr/share/haskell/haskell-clientsession/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: clientsession
version: 0.9.1.1
id: clientsession-0.9.1.1-b8e6f456b3509830746dc1bc910c0131
key: clien_9IM29FMu1faCDg0EecHqUM
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: stable
homepage: http://github.com/yesodweb/clientsession/tree/master
synopsis: Securely store session data in a client-side cookie.
description:
    Achieves security through AES-CTR encryption and
    Skein-MAC-512-256 authentication.  Uses Base64
    encoding to avoid any issues with characters.
category: Web
author: Michael Snoyman <michael@snoyman.com>, Felipe Lessa <felipe.lessa@gmail.com>
exposed: True
exposed-modules:
    Web.ClientSession
hidden-modules: System.LookupEnv
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/clientsession-0.9.1.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/clientsession-0.9.1.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/clientsession-0.9.1.1
hs-libraries: HSclientsession-0.9.1.1-9IM29FMu1faCDg0EecHqUM
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    cereal-0.5.1.0-2c7be146776a4abf674d1ac9e0ccfc13
    cipher-aes-0.2.11-78f8e669d2c7fa2c876e85f22e882b22
    cprng-aes-0.6.1-31f334ac9b899d0af12f1cbac49d2287
    crypto-api-0.13.2-095d0cf567bb83558b8b8ae881dd04fd
    crypto-random-0.0.9-bdb6a693941c8915b178724d04100946
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    entropy-0.3.7-db9feabff8921cc1dd6e8db21278a74f
    setenv-0.1.1.3-4d70f2e61b1bd0645017164a0ca26ee9
    skein-1.0.9.4-403a459122a5f86f1575bd5c2d5cfd5a
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
haddock-interfaces: /usr/share/doc/haskell-clientsession/html/clientsession.haddock
haddock-html: /usr/share/doc/haskell-clientsession/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-clientsession-0.9.1.1-5-armv7h.pkg.tar.xz: usr/share/haskell/haskell-clientsession/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: clientsession
version: 0.9.1.1
id: clientsession-0.9.1.1-460c757d370e23c2009b2fc0ceeee609
key: clien_4SEteLDzCqoKwhpXOD5S7S
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: stable
homepage: http://github.com/yesodweb/clientsession/tree/master
synopsis: Securely store session data in a client-side cookie.
description:
    Achieves security through AES-CTR encryption and
    Skein-MAC-512-256 authentication.  Uses Base64
    encoding to avoid any issues with characters.
category: Web
author: Michael Snoyman <michael@snoyman.com>, Felipe Lessa <felipe.lessa@gmail.com>
exposed: True
exposed-modules:
    Web.ClientSession
hidden-modules: System.LookupEnv
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/clientsession-0.9.1.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/clientsession-0.9.1.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/clientsession-0.9.1.1
hs-libraries: HSclientsession-0.9.1.1-4SEteLDzCqoKwhpXOD5S7S
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    cereal-0.5.1.0-2c7be146776a4abf674d1ac9e0ccfc13
    cipher-aes-0.2.11-78f8e669d2c7fa2c876e85f22e882b22
    cprng-aes-0.6.1-31f334ac9b899d0af12f1cbac49d2287
    crypto-api-0.13.2-6578ff0df46f6893eafa074007e52b3d
    crypto-random-0.0.9-bdb6a693941c8915b178724d04100946
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    entropy-0.3.7-db9feabff8921cc1dd6e8db21278a74f
    setenv-0.1.1.3-4d70f2e61b1bd0645017164a0ca26ee9
    skein-1.0.9.4-f2708f40ed7cebb6812369c52e8487ae
    tagged-0.8.4-af2e23230031c45949e0062e776a8f1f
haddock-interfaces: /usr/share/doc/haskell-clientsession/html/clientsession.haddock
haddock-html: /usr/share/doc/haskell-clientsession/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
